@@ -6,7 +6,6 @@ Functions to make IRF and other reconstruction quality-check plots
 
 
 import numpy as np
-import matplotlib as mpl
 import matplotlib.pyplot as plt
 from matplotlib.colors import LogNorm
 from scipy.stats import gaussian_kde, binned_statistic
@@ -17,35 +16,6 @@ from sklearn.multiclass import LabelBinarizer
 from ..io.dataset import load_any_resource
 from sklearn.preprocessing import label_binarize
 
-# plt.style.use('seaborn-colorblind')
-plt.style.use('seaborn-paper')
-
-# "#3F5D7D" is the nice dark blue color.
-
-
-SizeTitleArticle = 20
-SizeLabelArticle = 18
-SizeTickArticle = 16
-SizeTitleSlides = 28
-SizeLabelSlides = 24
-SizeTickSlides = 20
-
-SizeLabel = SizeLabelArticle
-SizeTick = SizeTickArticle
-
-mpl.rc('xtick', labelsize=SizeTick)
-mpl.rc('ytick', labelsize=SizeTick)
-mpl.rc('axes', labelsize=SizeLabel)
-
-# sets of colors from color-brewer
-BrewReds = ['#fee5d9', '#fcae91', '#fb6a4a', '#cb181d']
-BrewBlues = ['#eff3ff', '#bdd7e7', '#6baed6', '#2171b5']
-BrewGreens = ['#edf8e9', '#bae4b3', '#74c476', '#238b45']
-BrewGreys = ['#f7f7f7', '#cccccc', '#969696', '#525252']
-BrewViolets = ['#f2f0f7', '#cbc9e2', '#9e9ac8', '#6a51a3']
-BrewOranges = ['#feedde', '#fdbe85', '#fd8d3c', '#d94701']
-
-
 
 __all__ = ['plot_resolution',
            'plot_resolution_difference',
@@ -96,11 +66,9 @@ __all__ = ['plot_resolution',
            ]
 
 
-
-
 def plot_energy_distribution(mc_energy, reco_energy, ax=None, outfile=None, mask_mc_detected=True):
     """
-    Plot the energy distribution of the simulated particles, detected particles and reconstructed particles
+    Plot the true_energy distribution of the simulated particles, detected particles and reconstructed particles
     The plot might be saved automatically if `outfile` is provided.
 
     Parameters
@@ -129,7 +97,6 @@ def plot_energy_distribution(mc_energy, reco_energy, ax=None, outfile=None, mask
     count_S, bin_S, o = ax.hist(mc_energy, log=True, bins=np.logspace(-3, 3, 30), label="Simulated")
     count_D, bin_D, o = ax.hist(mc_energy[mask_mc_detected], log=True, bins=np.logspace(-3, 3, 30), label="Detected")
     count_R, bin_R, o = ax.hist(reco_energy, log=True, bins=np.logspace(-3, 3, 30), label="Reconstructed")
-    plt.legend(fontsize=SizeLabel)
     if outfile is not None:
         plt.savefig(outfile, bbox_inches="tight", format='png', dpi=200)
         plt.close()
@@ -139,7 +106,7 @@ def plot_energy_distribution(mc_energy, reco_energy, ax=None, outfile=None, mask
 
 def plot_multiplicity_per_energy(multiplicity, energies, ax=None, outfile=None):
     """
-    Plot the telescope multiplicity as a function of the energy
+    Plot the telescope multiplicity as a function of the true_energy
     The plot might be saved automatically if `outfile` is provided.
 
     Parameters
@@ -223,7 +190,7 @@ def plot_field_of_view_map(reco_alt, reco_az, source_alt, source_az, color_scale
         c = color_scale
         plt.colorbar()
     else:
-        c = BrewBlues[-1]
+        c = 'blue'
 
     ax.scatter(reco_az, reco_alt, c=c)
     ax.scatter(source_az, source_alt, marker='+', linewidths=3, s=200, c='orange', label="Source position")
@@ -255,11 +222,9 @@ def plot_angles_distribution(reco_alt, reco_az, source_alt, source_az, outfile=N
     -------
     fig: `matplotlib.pyplot.figure`
     """
-
+    fig = plt.figure()
     dx = 1
 
-    fig = plt.figure(figsize=(12, 9))
-
     ax1 = plt.subplot(211)
     ax1.spines["top"].set_visible(False)
     ax1.spines["right"].set_visible(False)
@@ -280,8 +245,6 @@ def plot_angles_distribution(reco_alt, reco_az, source_alt, source_az, outfile=N
     ax2.get_xaxis().tick_bottom()
     ax2.get_yaxis().tick_left()
 
-    ax2.set_xlabel('Alt [deg]', fontsize=SizeLabel)
-    ax2.set_ylabel('Count', fontsize=SizeLabel)
     ax2.set_xlim(source_alt - dx, source_alt + dx)
 
     ax2.hist(reco_alt, bins=60, range=(source_alt - dx, source_alt + dx))
@@ -362,13 +325,10 @@ def plot_angles_map_distri(reco_alt, reco_az, source_alt, source_az, energies, o
 
     dx = 0.01
 
-    fig = plt.figure(figsize=(12, 12))
+    fig = plt.figure()
 
     ax1 = plt.subplot2grid((4, 4), (0, 0), colspan=3, rowspan=3)
 
-    plt.xticks(fontsize=SizeTick)
-    plt.yticks(fontsize=SizeTick)
-
     ax1.set_xlim(source_az - dx, source_az + dx)
     ax1.set_ylim(source_alt - dx, source_alt + dx)
 
@@ -383,15 +343,12 @@ def plot_angles_map_distri(reco_alt, reco_az, source_alt, source_az, energies, o
     ax1.scatter(source_az, source_alt, marker='+', linewidths=3, s=200, c='black')
 
     ax1.xaxis.set_label_position('top')
-    ax1.yaxis.set_tick_params(labelsize=SizeTick)
     ax1.xaxis.set_ticks_position('top')
-    ax1.xaxis.set_tick_params(labelsize=SizeTick)
     plt.legend('', 'Source position')
 
     ax2 = plt.subplot2grid((4, 4), (3, 0), colspan=3)
     ax2.set_xlim(source_az - dx, source_az + dx)
     ax2.yaxis.tick_right()
-    ax2.xaxis.set_tick_params(labelsize=SizeTick)
     ax2.xaxis.set_ticklabels([])
     ax2.xaxis.tick_bottom()
     ax2.hist(reco_az, bins=60, range=(source_az - dx, source_az + dx))
@@ -400,7 +357,6 @@ def plot_angles_map_distri(reco_alt, reco_az, source_alt, source_az, energies, o
     ax3 = plt.subplot2grid((4, 4), (0, 3), rowspan=3)
     ax3.set_ylim(source_alt - dx, source_alt + dx)
     ax3.yaxis.set_ticklabels([])
-    ax3.yaxis.set_tick_params(labelsize=SizeTick)
     plt.locator_params(nbins=4)
 
     ax3.spines["left"].set_visible(False)
@@ -435,13 +391,10 @@ def plot_impact_point_map_distri(reco_x, reco_y, tel_x, tel_y, fit=False, outfil
     -------
     fig: `matplotlib.pyplot.figure`
     """
-    fig = plt.figure(figsize=(12, 12))
+    fig = plt.figure()
 
     ax1 = plt.subplot2grid((4, 4), (0, 0), colspan=3, rowspan=3)
 
-    plt.xticks(fontsize=SizeTick)
-    plt.yticks(fontsize=SizeTick)
-
     plt.xlabel("X [m]")
     plt.ylabel("Y [m]")
 
@@ -453,16 +406,13 @@ def plot_impact_point_map_distri(reco_x, reco_y, tel_x, tel_y, fit=False, outfil
         ax1.hist2d(reco_x, reco_y, bins=80, norm=LogNorm())
 
     ax1.xaxis.set_label_position('top')
-    ax1.yaxis.set_tick_params(labelsize=SizeTick)
     ax1.xaxis.set_ticks_position('top')
-    ax1.xaxis.set_tick_params(labelsize=SizeTick)
     plt.legend('', 'Source position')
 
     ax1.scatter(tel_x, tel_y, c='tomato', marker='+', s=90, linewidths=10)
 
     ax2 = plt.subplot2grid((4, 4), (3, 0), colspan=3)
     ax2.yaxis.tick_right()
-    ax2.xaxis.set_tick_params(labelsize=SizeTick)
     ax2.xaxis.set_ticklabels([])
     ax2.xaxis.tick_bottom()
     ax2.hist(reco_x, bins=60)
@@ -470,7 +420,6 @@ def plot_impact_point_map_distri(reco_x, reco_y, tel_x, tel_y, fit=False, outfil
 
     ax3 = plt.subplot2grid((4, 4), (0, 3), rowspan=3)
     ax3.yaxis.set_ticklabels([])
-    ax3.yaxis.set_tick_params(labelsize=SizeTick)
     plt.locator_params(nbins=4)
 
     ax3.spines["left"].set_visible(False)
@@ -499,9 +448,6 @@ def plot_impact_point_heatmap(reco_x, reco_y, ax=None, outfile=None):
 
     ax = plt.gca() if ax is None else ax
 
-    ax.set_xticklabels(ax.get_xticklabels(), fontsize=SizeTick)
-    ax.set_yticklabels(ax.get_yticklabels(), fontsize=SizeTick)
-
     ax.set_xlabel("X [m]")
     ax.set_ylabel("Y [m]")
     ax.axis('equal')
@@ -548,11 +494,10 @@ def plot_multiplicity_hist(multiplicity, ax=None, outfile=None, quartils=False,
     x50 = m[int(np.floor(0.5 * len(m)))] + 0.5
     x90 = m[int(np.floor(0.9 * len(m)))] + 0.5
     if quartils and (xmin < x50 < xmax):
-        ax.vlines(x50, 0, n[int(m[int(np.floor(0.5 * len(m)))])], color=BrewOranges[-2], label='50%')
+        ax.vlines(x50, 0, n[int(m[int(np.floor(0.5 * len(m)))])], label='50%')
     if quartils and (xmin < x90 < xmax):
-        ax.vlines(x90, 0, n[int(m[int(np.floor(0.9 * len(m)))])], color=BrewOranges[-1], label='90%')
+        ax.vlines(x90, 0, n[int(m[int(np.floor(0.9 * len(m)))])], label='90%')
 
-    ax.legend(fontsize=SizeLabel)
     ax.set_title("Telescope multiplicity")
     if type(outfile) is str:
         plt.savefig(outfile, bbox_inches="tight", format='png', dpi=200)
@@ -606,9 +551,8 @@ def plot_multiplicity_per_telescope_type(multiplicity, telescope_type, ax=None,
     if quartils and (xmin < x50 < xmax):
         ax.vlines(x50+0.5, 0, len(multiplicity[multiplicity==x50]), label='50%')
     if quartils and (xmin < x90 < xmax):
-        ax.vlines(x90+0.5, 0, len(multiplicity[multiplicity==x90]), color=BrewOranges[-1], label='90%')
+        ax.vlines(x90+0.5, 0, len(multiplicity[multiplicity==x90]), label='90%')
 
-    ax.legend(fontsize=SizeLabel)
     ax.set_title("Telescope multiplicity")
     if type(outfile) is str:
         plt.savefig(outfile, bbox_inches="tight", format='png', dpi=200)
@@ -662,7 +606,7 @@ def plot_resolution(bins, res, log=False, ax=None, **kwargs):
 
 def plot_effective_area_per_energy(simu_energy, reco_energy, simulated_area, ax=None, **kwargs):
     """
-    Plot the effective area as a function of the energy
+    Plot the effective area as a function of the true energy
 
     Parameters
     ----------
@@ -694,7 +638,7 @@ def plot_effective_area_per_energy(simu_energy, reco_energy, simulated_area, ax=
     ax.spines["right"].set_visible(False)
     ax.get_xaxis().tick_bottom()
     ax.get_yaxis().tick_left()
-    ax.set_xlabel('Energy [TeV]')
+    ax.set_xlabel(r'Energy\textsubscript{true} [TeV]')
     ax.set_ylabel(r'Effective Area $[m^2]$')
     ax.set_xscale('log')
     ax.set_yscale('log')
@@ -706,13 +650,13 @@ def plot_effective_area_per_energy(simu_energy, reco_energy, simulated_area, ax=
         kwargs['fmt'] = 'o'
 
     ax.errorbar(E, Seff, xerr=(E_bin[1:] - E_bin[:-1]) / 2., **kwargs)
-
+    ax.grid('on', which='both')
     return ax
 
 
 def plot_effective_area_cta_requirement(cta_site, ax=None, **kwargs):
     """
-    Plot the CTA requirement for the effective area
+    Plot the CTA requirement for the effective area as a function of the true energy
 
     Parameters
     ----------
@@ -732,20 +676,21 @@ def plot_effective_area_cta_requirement(cta_site, ax=None, **kwargs):
 
     ax.set_xscale('log')
     ax.set_yscale('log')
-    ax.set_xlabel('Energy [TeV]')
+    ax.set_xlabel(r'Energy\textsubscript{true} [TeV]')
     ax.set_ylabel(r'Effective Area $[m^2]$')
 
     if not 'label' in kwargs:
         kwargs['label'] = "CTA requirement {}".format(cta_site)
 
     ax.plot(e_cta, ef_cta, **kwargs)
-
+    ax.grid('on', which='both')
+    ax.legend()
     return ax
 
 
 def plot_effective_area_cta_performance(cta_site, ax=None, **kwargs):
     """
-    Plot the CTA performances for the effective area
+    Plot the CTA performances for the effective area as a function of the true energy
 
     Parameters
     ----------
@@ -765,18 +710,18 @@ def plot_effective_area_cta_performance(cta_site, ax=None, **kwargs):
 
     ax.set_xscale('log')
     ax.set_yscale('log')
-    ax.set_xlabel('Energy [TeV]')
+    ax.set_xlabel(r'Energy\textsubscript{true} [TeV]')
     ax.set_ylabel(r'Effective Area $[m^2]$')
 
     if not 'label' in kwargs:
         kwargs['label'] = "CTA performance {}".format(cta_site)
 
     ax.plot(e_cta, ef_cta, **kwargs)
-
+    ax.grid('on', which='both')
+    ax.legend()
     return ax
 
 
-
 def plot_sensitivity_cta_requirement(cta_site, ax=None, **kwargs):
     """
     Plot the CTA requirement for the sensitivity
@@ -799,14 +744,15 @@ def plot_sensitivity_cta_requirement(cta_site, ax=None, **kwargs):
 
     ax.set_xscale('log')
     ax.set_yscale('log')
-    ax.set_xlabel('Energy [TeV]')
+    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
     ax.set_ylabel(r'Flux Sensitivity $[erg.cm^{-2}.s^{-1}]$')
 
     if not 'label' in kwargs:
         kwargs['label'] = "CTA requirement {}".format(cta_site)
 
     ax.plot(e_cta, ef_cta, **kwargs)
-
+    ax.grid('on', which='both')
+    ax.legend()
     return ax
 
 
@@ -828,19 +774,21 @@ def plot_sensitivity_cta_performance(cta_site, ax=None, **kwargs):
 
     ax = plt.gca() if ax is None else ax
 
-    cta_req = ana.cta_performance(cta_site)
-    e_cta, ef_cta = cta_req.get_sensitivity()
+    cta_perf = ana.cta_performance(cta_site)
+    e_cta, ef_cta = cta_perf.get_sensitivity()
+    e_bin = cta_perf.E_bin
 
     ax.set_xscale('log')
     ax.set_yscale('log')
-    ax.set_xlabel('Energy [TeV]')
+    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
     ax.set_ylabel(r'Flux Sensitivity $[erg.cm^{-2}.s^{-1}]$')
 
     if not 'label' in kwargs:
         kwargs['label'] = "CTA performance {}".format(cta_site)
 
-    ax.plot(e_cta, ef_cta, **kwargs)
-
+    ax.errorbar(e_cta, ef_cta, xerr=np.array([e_cta-e_bin[:-1], e_bin[1:]-e_cta]), **kwargs)
+    ax.grid('on', which='both')
+    ax.legend()
     return ax
 
 
@@ -878,7 +826,7 @@ def plot_layout_map(tel_x, tel_y, tel_type=None, ax=None, **kwargs):
 
 def plot_resolution_per_energy(reco, simu, energy, ax=None, **kwargs):
     """
-    Plot a variable resolution as a function of the energy
+    Plot a variable resolution as a function of the true_energy
 
     Parameters
     ----------
@@ -915,16 +863,16 @@ def plot_resolution_per_energy(reco, simu, energy, ax=None, **kwargs):
 
     ax.errorbar(E, resolution[:, 0], xerr=(energy_bin[1:] - energy_bin[:-1]) / 2.,
                 yerr=(resolution[:, 0] - resolution[:, 1], resolution[:, 2] - resolution[:, 0]), **kwargs)
-
+    ax.grid('on', which='both')
     ax.set_title('Resolution')
     return ax
 
 
-def plot_angular_resolution_per_energy(reco_alt, reco_az, mc_alt, mc_az, energy,
+def plot_angular_resolution_per_energy(reco_alt, reco_az, mc_alt, mc_az, reco_energy,
                                        percentile=68.27, confidence_level=0.95, bias_correction=False,
                                        ax=None, **kwargs):
     """
-    Plot the angular resolution as a function of the energy
+    Plot the angular resolution as a function of the reconstructed energy
 
     Parameters
     ----------
@@ -936,7 +884,7 @@ def plot_angular_resolution_per_energy(reco_alt, reco_az, mc_alt, mc_az, energy,
         true altitudes in radians
     mc_az: `numpy.ndarray`
         true azimuths in radians
-    energy: `numpy.ndarray`
+    reco_energy: `numpy.ndarray`
         energies in TeV
     ax: `matplotlib.pyplot.axes`
     kwargs: args for `matplotlib.pyplot.errorbar`
@@ -949,7 +897,7 @@ def plot_angular_resolution_per_energy(reco_alt, reco_az, mc_alt, mc_az, energy,
     ax = plt.gca() if ax is None else ax
 
     try:
-        e_bin, RES = ana.angular_resolution_per_energy(reco_alt, reco_az, mc_alt, mc_az, energy,
+        e_bin, RES = ana.angular_resolution_per_energy(reco_alt, reco_az, mc_alt, mc_az, reco_energy,
                                                        percentile=percentile,
                                                        confidence_level=confidence_level,
                                                        bias_correction=bias_correction
@@ -965,13 +913,14 @@ def plot_angular_resolution_per_energy(reco_alt, reco_az, mc_alt, mc_az, energy,
         if 'fmt' not in kwargs:
             kwargs['fmt'] = 'o'
 
-        ax.set_ylabel(r'$\theta [deg]$')
-        ax.set_xlabel('Energy [TeV]')
+        ax.set_ylabel('Angular Resolution [deg]')
+        ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
         ax.set_xscale('log')
         ax.set_title('Angular resolution')
 
         ax.errorbar(E, RES[:, 0], xerr=(e_bin[1:] - e_bin[:-1]) / 2.,
                     yerr=(RES[:, 0] - RES[:, 1], RES[:, 2] - RES[:, 0]), **kwargs)
+        ax.grid('on', which='both')
     finally:
         return ax
 
@@ -1000,11 +949,13 @@ def plot_angular_resolution_cta_requirement(cta_site, ax=None, **kwargs):
 
     ax.plot(e_cta, ar_cta, **kwargs)
 
-    ax.set_ylabel(r'$\theta [deg]$')
-    ax.set_xlabel('Energy [TeV]')
+    ax.set_ylabel(r'Angular Resolution [deg]')
+    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
 
     ax.set_xscale('log')
     ax.set_title('Angular resolution')
+    ax.grid('on', which='both')
+    ax.legend()
     return ax
 
 
@@ -1033,9 +984,11 @@ def plot_angular_resolution_cta_performance(cta_site, ax=None, **kwargs):
 
     ax.plot(e_cta, ar_cta, **kwargs)
     ax.set_xscale('log')
-    ax.set_ylabel(r'$\theta [deg]$')
-    ax.set_xlabel('Energy [TeV]')
+    ax.set_ylabel('Angular resolution [deg]')
+    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
     ax.set_title('Angular resolution')
+    ax.grid('on', which='both')
+    ax.legend()
     return ax
 
 
@@ -1071,7 +1024,7 @@ def hist_impact_parameter_error(reco_x, reco_y, simu_x, simu_y, ax=None, **kwarg
                                   'Use `plot_impact_parameter_resolution_per_energy` instead')
 def plot_impact_parameter_error_per_energy(reco_x, reco_y, simu_x, simu_y, energy, ax=None, **kwargs):
     """
-    plot the impact parameter error distance as a function of energy and save the plot as Outfile
+    plot the impact parameter error distance as a function of true_energy and save the plot as Outfile
     
     Parameters
     ----------
@@ -1085,7 +1038,7 @@ def plot_impact_parameter_error_per_energy(reco_x, reco_y, simu_x, simu_y, energ
 
     Returns
     -------
-    energy, err_mean : numpy arrays
+    true_energy, err_mean : numpy arrays
     """
     irf = ana.irf_cta()
     E_bin = irf.E_bin
@@ -1123,7 +1076,6 @@ def plot_impact_parameter_error_per_energy(reco_x, reco_y, simu_x, simu_y, energ
     ax.fill_between(E, err_min, err_max)
     ax.errorbar(E, err_mean, err_std, color="red", label="mean+std")
 
-    plt.legend(fontsize=SizeLabel)
     ax.set_title('Impact parameter resolution')
 
     return E, np.array(err_mean)
@@ -1150,8 +1102,8 @@ def plot_impact_parameter_resolution_per_energy(reco_x, reco_y, simu_x, simu_y,
     ax = plot_resolution(bin, res, log=True, ax=ax, **kwargs)
     ax.set_xlabel("Energy")
     ax.set_ylabel("Impact parameter resolution")
-    ax.set_title("Impact parameter resolution as a function of the energy")
-
+    ax.set_title("Impact parameter resolution as a function of the true_energy")
+    ax.grid('on', which='both')
     return ax
 
 
@@ -1208,8 +1160,6 @@ def plot_impact_parameter_error_per_multiplicity(reco_x, reco_y, simu_x, simu_y,
     ax.fill_between(M, e_min, e_max)
     ax.errorbar(M, e_mean, e_std, color="red", label="mean+std")
 
-    plt.legend(fontsize=SizeLabel)
-
     return M, np.array(e_mean)
 
 
@@ -1263,7 +1213,7 @@ def plot_impact_map(impact_x, impact_y, tel_x, tel_y, tel_types=None,
 
 def plot_energy_bias(simu_energy, reco_energy, ax=None, **kwargs):
     """
-    Plot the energy bias
+    Plot the true_energy bias
 
     Parameters
     ----------
@@ -1276,7 +1226,7 @@ def plot_energy_bias(simu_energy, reco_energy, ax=None, **kwargs):
     -------
     ax: `matplotlib.pyplot.axes`
     """
-    assert len(simu_energy) == len(reco_energy), "simulated and reconstructured energy arrrays should have the same length"
+    assert len(simu_energy) == len(reco_energy), "simulated and reconstructured true_energy arrrays should have the same length"
 
     ax = plt.gca() if ax is None else ax
 
@@ -1287,11 +1237,12 @@ def plot_energy_bias(simu_energy, reco_energy, ax=None, **kwargs):
         kwargs['fmt'] = 'o'
 
     ax.set_ylabel("bias (median($E_{reco}/E_{simu}$ - 1)")
-    ax.set_xlabel("log(E/TeV)")
+    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
     ax.set_xscale('log')
     ax.set_title('Energy bias')
 
     ax.errorbar(E, biasE, xerr=(E - E_bin[:-1], E_bin[1:] - E), **kwargs)
+    ax.grid('on', which='both')
 
     return ax
 
@@ -1300,7 +1251,7 @@ def plot_energy_resolution(simu_energy, reco_energy,
                            percentile=68.27, confidence_level=0.95, bias_correction=False,
                            ax=None, **kwargs):
     """
-    Plot the enregy resolution as a function of the energy
+    Plot the enregy resolution as a function of the true_energy
 
     Parameters
     ----------
@@ -1314,7 +1265,7 @@ def plot_energy_resolution(simu_energy, reco_energy,
     -------
     ax: `matplotlib.pyplot.axes`
     """
-    assert len(simu_energy) == len(reco_energy), "simulated and reconstructured energy arrrays should have the same length"
+    assert len(simu_energy) == len(reco_energy), "simulated and reconstructured true_energy arrrays should have the same length"
 
     ax = plt.gca() if ax is None else ax
 
@@ -1333,19 +1284,21 @@ def plot_energy_resolution(simu_energy, reco_energy,
             kwargs['fmt'] = 'o'
 
         ax.set_ylabel(r"$(\Delta E/E)_{68}$")
-        ax.set_xlabel("Energy [TeV]")
+        ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
         ax.set_xscale('log')
         ax.set_title('Energy resolution')
 
         ax.errorbar(E, Eres[:, 0], xerr=(E - E_bin[:-1], E_bin[1:] - E),
                     yerr=(Eres[:, 0] - Eres[:, 1], Eres[:, 2] - Eres[:, 0]), **kwargs)
+
+        ax.grid('on', which='both')
     finally:
         return ax
 
 
 def plot_energy_resolution_cta_requirement(cta_site, ax=None, **kwargs):
     """
-    Plot the cta requirement for the energy resolution
+    Plot the cta requirement for the true_energy resolution
 
     Parameters
     ----------
@@ -1367,15 +1320,17 @@ def plot_energy_resolution_cta_requirement(cta_site, ax=None, **kwargs):
         kwargs['label'] = "CTA requirement {}".format(cta_site)
 
     ax.set_ylabel(r"$(\Delta E/E)_{68}$")
-    ax.set_xlabel("Energy [TeV]")
+    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
     ax.plot(e_cta, ar_cta, **kwargs)
     ax.set_xscale('log')
+    ax.grid('on', which='both')
+    ax.legend()
     return ax
 
 
 def plot_energy_resolution_cta_performance(cta_site, ax=None, **kwargs):
     """
-    Plot the cta performances (June 2018) for the energy resolution
+    Plot the cta performances (June 2018) for the true_energy resolution
 
     Parameters
     ----------
@@ -1397,9 +1352,11 @@ def plot_energy_resolution_cta_performance(cta_site, ax=None, **kwargs):
         kwargs['label'] = "CTA performance {}".format(cta_site)
 
     ax.set_ylabel(r"$(\Delta E/E)_{68}$")
-    ax.set_xlabel("Energy [TeV]")
+    ax.set_xlabel(r'Energy\textsubscript{reco} [TeV]')
     ax.plot(e_cta, ar_cta, **kwargs)
     ax.set_xscale('log')
+    ax.grid('on', which='both')
+    ax.legend()
     return ax
 
 
@@ -1429,6 +1386,7 @@ def plot_impact_parameter_error_site_center(reco_x, reco_y, simu_x, simu_y, ax=N
     ax.hist2d(distance_center, imp_err, **kwargs)
     ax.set_xlabel("Distance to site center")
     ax.set_ylabel("Impact point error")
+    ax.grid('on', which='both')
     return ax
 
 
@@ -1436,7 +1394,7 @@ def plot_impact_resolution_per_energy(reco_x, reco_y, simu_x, simu_y, simu_energ
                                       percentile=68.27, confidence_level=0.95, bias_correction=False,
                                       ax=None, **kwargs):
     """
-    Plot the angular resolution as a function of the energy
+    Plot the angular resolution as a function of the true_energy
 
     Parameters
     ----------
@@ -1478,6 +1436,7 @@ def plot_impact_resolution_per_energy(reco_x, reco_y, simu_x, simu_y, simu_energ
             yerr=(RES[:, 0] - RES[:, 1], RES[:, 2] - RES[:, 0]),
             **kwargs,
             )
+        ax.grid('on', which='both')
     finally:
         return ax
 
@@ -1656,23 +1615,23 @@ def plot_binned_stat(x, y, statistic='mean', bins=20, errorbar=False, percentile
 
 
 def plot_effective_area_per_energy_power_law(emin, emax, total_number_events, spectral_index,
-                                             reco_energy, simu_area, ax=None, **kwargs):
+                                             true_energy, simu_area, ax=None, **kwargs):
     """
-    Plot the effective area as a function of the energy.
+    Plot the effective area as a function of the true energy.
     The effective area is computed using the `ctaplot.ana.effective_area_per_energy_power_law`.
 
     Parameters
     ----------
     emin: float
-        min simulated energy
+        min simulated reco_energy
     emax: float
-        max simulated energy
+        max simulated reco_energy
     total_number_events: int
         total number of simulated events
     spectral_index: float
         spectral index of the simulated power-law
-    reco_energy: `numpy.ndarray`
-        reconstructed energies
+    true_energy: `numpy.ndarray`
+        true energies of the reconstructed events
     simu_area: float
         simulated core area
     ax: `matplotlib.pyplot.axes`
@@ -1689,20 +1648,20 @@ def plot_effective_area_per_energy_power_law(emin, emax, total_number_events, sp
     ax.spines["right"].set_visible(False)
     ax.get_xaxis().tick_bottom()
     ax.get_yaxis().tick_left()
-    ax.set_xlabel('Energy [TeV]')
+    ax.set_xlabel(r'Energy\textsubscript{true} [TeV]')
     ax.set_ylabel(r'Effective Area $[m^2]$')
     ax.set_xscale('log')
     ax.set_yscale('log')
 
     ebin, seff = ana.effective_area_per_energy_power_law(emin, emax, total_number_events,
-                                                         spectral_index, reco_energy, simu_area)
+                                                         spectral_index, true_energy, simu_area)
 
     energy_nodes = ana.logbin_mean(ebin)
 
     if 'fmt' not in kwargs:
         kwargs['fmt'] = 'o'
     ax.errorbar(energy_nodes, seff, xerr=(ebin[1:] - ebin[:-1]) / 2., **kwargs)
-
+    ax.grid('on', which='both')
     return ax
 
 
@@ -1734,15 +1693,15 @@ def plot_angular_resolution_per_off_pointing_angle(simu_alt, simu_az, reco_alt,
     """
     res_bins, res = ana.angular_resolution_per_off_pointing_angle(simu_alt, simu_az, reco_alt, reco_az,
                                                                   alt_pointing, az_pointing, bins=bins)
-    res_unit='rad'
+    res_unit = 'rad'
     if res_degree:
         res = np.rad2deg(res)
-        res_unit='deg'
+        res_unit = 'deg'
 
     ax = plot_resolution(res_bins, res, ax=ax, **kwargs)
     ax.set_xlabel("Angular separation to pointing direction [rad]")
     ax.set_ylabel("Angular resolution [{}]".format(res_unit))
-
+    ax.grid('on', which='both')
     return ax
 
 
@@ -1796,7 +1755,7 @@ def plot_binned_bias(simu, reco, x, relative_scaling_method=None, ax=None, bins=
     assert len(simu) == len(reco), \
         "simu and reco arrays should have the same length"
     assert len(simu) == len(x), \
-        "simu and energy arrays should have the same length"
+        "simu and true_energy arrays should have the same length"
 
     ax = plt.gca() if ax is None else ax
 
@@ -1824,7 +1783,7 @@ def plot_binned_bias(simu, reco, x, relative_scaling_method=None, ax=None, bins=
 
 def plot_bias_per_energy(simu, reco, energy, relative_scaling_method=None, ax=None, **kwargs):
     """
-    Plot the bias per bins of energy
+    Plot the bias per bins of true_energy
 
     Parameters
     ----------
@@ -1843,7 +1802,7 @@ def plot_bias_per_energy(simu, reco, energy, relative_scaling_method=None, ax=No
     assert len(simu) == len(reco), \
         "simu and reco arrays should have the same length"
     assert len(simu) == len(energy), \
-        "simu and energy arrays should have the same length"
+        "simu and true_energy arrays should have the same length"
 
     ax = plt.gca() if ax is None else ax
 
@@ -1858,7 +1817,7 @@ def plot_bias_per_energy(simu, reco, energy, relative_scaling_method=None, ax=No
     ax.set_xscale('log')
 
     ax.errorbar(mean_bins, bias, xerr=(mean_bins - bins[:-1], bins[1:] - mean_bins), **kwargs)
-
+    ax.grid('on', which='both')
     return ax
 
 
@@ -2083,7 +2042,7 @@ def plot_roc_curve_gammaness_per_energy(simu_type, gammaness, simu_energy, gamma
                                         ax=None,
                                         **kwargs):
     """
-    Plot a gamma ROC curve per gamma energy bin.
+    Plot a gamma ROC curve per gamma true_energy bin.
 
     Parameters
     ----------
@@ -2092,11 +2051,11 @@ def plot_roc_curve_gammaness_per_energy(simu_type, gammaness, simu_energy, gamma
     gammaness: `numpy.ndarray`
         probability of each event to be a gamma, values must be between 0 and 1
     simu_energy: `numpy.ndarray`
-        energy of the gamma events in TeV
+        true_energy of the gamma events in TeV
         simu_energy.shape == simu_type.shape (but energies for events that are not gammas are not considered)
     gamma_label: the label of the gamma class in `simu_type`.
     energy_bins: None or int or `numpy.ndarray`
-        bins in energy.
+        bins in true_energy.
         If `bins` is None, the default binning given by `ctaplot.ana.irf_cta().E_bin` if used.
         If `bins` is an int, it defines the number of equal-width
         bins in the given range.
@@ -2215,7 +2174,7 @@ def plot_gammaness_distribution(mc_type, gammaness, ax=None, **kwargs):
             kwargs['label'] = particle
         ax.hist(gammaness[mc_type == particle], **kwargs)
 
-    ax.set_title('Gammaness distribution per particle type', fontsize=18)
+    ax.set_title('Gammaness distribution per particle type')
     ax.set_xlabel('gammaness')
-    ax.legend(fontsize=15)
+    ax.legend()
     return ax
